pub struct Callable { /* private fields */ }Expand description
Either a path or a closure.
This type is useful for options that historically took a path,
e.g. #[darling(with = ...)] or #[serde(skip_serializing_if = ...)]
and now want to also allow using a closure to avoid needing a separate
function declaration.
In darling, this value is wrapped in core::convert::identity before usage;
this allows treatment of the closure and path cases as equivalent, and prevents
a closure from accessing locals in the generated code.